DragEndEvent class
拖拽地图停止事件
Constructors
- DragEndEvent(int mapId, Position position)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mapId → int
-
The ID of the Map this event is associated to.
finalinherited
- position → Position
-
The latLng where this event happened.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → void
-
The value wrapped by this event
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited